@@ -24,7 +24,7 @@
 Button::Button(const QString &text, QWidget *parent)
     : QPushButton(parent)
 {
-    setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
+    setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     setText(text);
 }
 
