@@ -27,7 +27,10 @@
 #include <QMessageAddress>
 #include <QMenuBar>
 #include <QMainWindow>
-//#include <QContactManager>
+
+#if defined(Q_WS_MAEMO_5)
+#include <QMaemo5InformationBox>
+#endif
 
 #define STATE_SPACE 0
 #define STATE_SYM 1
@@ -60,7 +63,7 @@
 
 #define ACTION_INS 0
 #define ACTION_DEL 1
-#define ACTION_SEND 1
+#define ACTION_SEND 2
 
 #define DATA_PATH "/data/"
 
@@ -160,11 +163,10 @@ QTM_USE_NAMESPACE
     m_nCharCount = 160;
     m_nSMSCount = 1;
     //init variables for capitalization
-    m_bMustCapitalize = true;
     m_sCapitalization = CAPITALIZATION_CHAR;
     m_nInputSyle = IN_STYLE_CAPITALIZE;
     m_bFastInput = true;
-    m_bNewChar = true;
+    m_bRememberUppercase = false;
     //init variables for standard input style
     m_bTimerNewChar = true;
     timerNewChar = new QTimer(this);
@@ -491,8 +493,6 @@ Button *Fastsms::createButton(const QString &text, const char *member)
 
 void Fastsms::digitClicked()
 {
-
-    //Button *clickedButton = qobject_cast<Button *>(sender());
     QPushButton *clickedButton = qobject_cast<QPushButton *>(sender());
     QString lastPress = clickedButton->text().at(0);
 
@@ -616,25 +616,12 @@ void Fastsms::digitClicked()
 
             if(!m_bTimerNewChar && lastPress.compare(m_sLastPress) == 0)
             {
-                m_bNewChar = false;
-
-                //Manage capitalization
-                int nPos = m_cursorSmsText.position();
-                nPos--;
-
-                if(m_bWasCapitalized)
-                    m_bMustCapitalize = true;
-                else
-                    m_bMustCapitalize = false;
-                //
-
                 nextWord();
                 timerNewChar->start();
             }
             else
             {
-                m_bNewChar = true;
-                m_bWasCapitalized = false;
+                m_bRememberUppercase = false;
                 m_nState = STATE_SYM;
                 m_nMsgLength++;
                 m_sCompleteValue.clear();
@@ -805,39 +792,43 @@ QString Fastsms::capitalizeIfNeeded(QString sWord)
 {
     if(m_nInputSyle == IN_STYLE_CAPITALIZE)
     {
-        if(m_sCapitalization.contains(sWord))
-            m_bMustCapitalize = true;
-        else if(m_dict->isSymbol(sWord[0]))
-            m_bMustCapitalize = false;
-        else if(sWord==" ")
-            m_bMustCapitalize = false;
+        QString smsText = m_smsEdit->toPlainText();
+        int nIdx = m_cursorSmsText.position();
 
+        smsText.length() <= nIdx ? nIdx = smsText.length() -1 :  nIdx = nIdx;
 
-        if(!m_bFastInput && m_bNewChar)
+        bool bToUpper = true;
+        bool bSpace = false;
+
+        for(int i=nIdx; i>=0; i--)
         {
-            int nPos = m_cursorSmsText.position();
-            if(nPos > 0)
+            if(smsText.at(i) == ' ')
             {
-                nPos--;
+                bSpace = true;
+                continue;
+            }
 
-                if(m_sCapitalization.contains(m_smsEdit->toPlainText().at(nPos)))
+            if(bSpace || !m_bFastInput)
+            {
+                if(!m_sCapitalization.contains(smsText.at(i)))
                 {
-                    sWord[0]=sWord[0].toUpper();
-                    m_bWasCapitalized = true;
+                    bToUpper = false;
+                    break;
+                }
+                else
+                {
+                    break;
                 }
             }
-            else
-            {
-                sWord[0]=sWord[0].toUpper();
-                m_bWasCapitalized = true;
-            }
         }
-        else if(m_bMustCapitalize)
+
+        if(bToUpper || m_bRememberUppercase)
         {
             sWord[0]=sWord[0].toUpper();
+
+            if(!m_bFastInput)
+                m_bRememberUppercase = true;
         }
-
-
     }
     else if(m_nInputSyle == IN_STYLE_UPPER)
         sWord = sWord.toUpper();
@@ -954,6 +945,13 @@ void Fastsms::sendSMS()
 
                 if(isSmsAccount)
                 {
+                    //Message box
+                    #if defined(Q_WS_MAEMO_5)
+
+                    QMaemo5InformationBox::information(this, "Sending...",
+                                                       QMaemo5InformationBox::DefaultTimeout);
+                    #endif
+                    //
                     QMessage myMessage;
                     myMessage.setType(QMessage::Sms);
                     myMessage.setParentAccountId(lstMsgAccountId[i]);
@@ -1032,6 +1030,10 @@ void Fastsms::chageInputStyle()
     }
     else if(action->data() == IN_STYLE_FW_ON)
     {
+        //Rest FastWrite state
+        ui->btZero->click();
+        ui->btDelChar->click();
+        //
         action->setText("Disable FastWrite");
         action->setData(IN_STYLE_FW_OFF);
         m_bFastInput = true;
